@@ -7,7 +7,7 @@ use HTTP::Tiny;
 use Parse::CPAN::Packages;
 use Module::Extract::Namespaces;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 has darkpan_url                   => (is => 'ro', required => 1);
 has missing_modules               => (is => 'rw', default => sub { [] });
@@ -61,7 +61,7 @@ sub darkpan {
 # returns: { $package => $version, ... }
 sub get_pkgs_from_local_environment {
     my $self = shift;
-    my $inst = ExtUtils::Installed->new;
+    my $inst = ExtUtils::Installed->new(skip_cwd => 1);
     my @modules = $inst->modules;
 
     my $local_modules;
